# G3SHVNodes: A node-centric wrapper of the PySHV library

The **G3SHVNodes** library provides the ``SHVNode`` class — a node-centric
wrapper of the ``shv.ValueClient`` class, which allows to work with nodes as
*objects*. See documentation for more information.

## Installation

The installation can be done with the package manager `pip`.

```console
$ pip install g3shvnodes
```
